@@ -15,14 +15,14 @@ namespace ARTICLE
         std::string m_url_messageview;
 
       public:
-        ArticleViewPreview( const std::string& url );
+        explicit ArticleViewPreview( const std::string& url );
         ~ArticleViewPreview();
 
         bool operate_view( const int control ) override;
 
       private:
 
-        bool slot_button_press( std::string url, int res_number, GdkEventButton* event ) override;
+        bool slot_button_press( const std::string& url, int res_number, GdkEventButton* event ) override;
 
         void goto_num( const int num_to, const int num_from ) override {}
     };
