@@ -10,9 +10,11 @@
 
 #include "skeleton/dispatchable.h"
 
-#include "jdlib/jdthread.h"
 #include "jdlib/imgloader.h"
 
+#include <thread>
+
+
 namespace DBIMG
 {
     class Img;
@@ -25,7 +27,7 @@ namespace ARTICLE
         std::string m_url;
         Glib::RefPtr< Gdk::Pixbuf > m_pixbuf;
         DBIMG::Img* m_img;
-        JDLIB::Thread m_thread;
+        std::thread m_thread;
 
         Glib::RefPtr< JDLIB::ImgLoader > m_imgloader;
 
