@@ -64,18 +64,18 @@ bool SelectListView::operate_view( const int control )
 Gtk::Menu* SelectListView::get_popupmenu( const std::string& url )
 {
     Gtk::Menu* popupmenu;
-    if( url.empty() ) popupmenu = id2popupmenu(  "/popup_menu_favorite_space" );
+    if( url.empty() ) popupmenu = id2popupmenu(  "popup_menu_favorite_space" );
     else{
         std::list< Gtk::TreeModel::iterator > list_it = get_treeview().get_selected_iterators();
         if( list_it.size() == 1 ){
 
             int type = path2type( *( get_treeview().get_selection()->get_selected_rows().begin() ) );
 
-            if( type == TYPE_DIR ) popupmenu = id2popupmenu(  "/popup_menu_favorite_dir" );
-            else if( type == TYPE_COMMENT ) popupmenu = id2popupmenu(  "/popup_menu_favorite_com" );
-            else popupmenu = id2popupmenu(  "/popup_menu_select" );
+            if( type == TYPE_DIR ) popupmenu = id2popupmenu(  "popup_menu_favorite_dir" );
+            else if( type == TYPE_COMMENT ) popupmenu = id2popupmenu(  "popup_menu_favorite_com" );
+            else popupmenu = id2popupmenu(  "popup_menu_select" );
         }
-        else popupmenu = id2popupmenu(  "/popup_menu_favorite_mul" );
+        else popupmenu = id2popupmenu(  "popup_menu_favorite_mul" );
     }
 
     return popupmenu;
