@@ -70,9 +70,8 @@ namespace BOARD
 
         // クッキー と キーワード表示
         Gtk::Frame m_frame_cookie;
-        Gtk::HBox m_hbox_cookie;
+        Gtk::Grid m_grid_cookie;
         SKELETON::EditView m_edit_cookies;
-        Gtk::VBox m_vbox_cookie;
         Gtk::Button m_button_cookie;
 
         // 実況の更新間隔
@@ -81,9 +80,17 @@ namespace BOARD
         Gtk::CheckButton m_check_live;
         Gtk::SpinButton m_spin_live;
 
+        // ネットワーク設定
+        Gtk::Box m_vbox_network;
+
+        // ユーザーエージェント
+        Gtk::Label m_comment_agent;
+        Gtk::Box m_hbox_agent;
+        Gtk::Label m_label_agent;
+        Gtk::Entry m_entry_agent;
+
         // プロキシ
-        Gtk::VBox m_vbox_proxy;
-        Gtk::Label m_label_proxy;
+        Gtk::Label m_comment_proxy;
         ProxyFrame m_proxy_frame;
         ProxyFrame m_proxy_frame_w;
 
@@ -128,9 +135,13 @@ namespace BOARD
         Gtk::VBox m_vbox_abone_thread;
         Gtk::Label m_label_abone_thread;
 
-        Gtk::HBox m_hbox_number;
-        Gtk::Label m_label_number;
-        Gtk::SpinButton m_spin_number;
+        Gtk::Box m_hbox_low_number;
+        Gtk::Label m_label_low_number;
+        Gtk::SpinButton m_spin_low_number;
+
+        Gtk::Box m_hbox_high_number;
+        Gtk::Label m_label_high_number;
+        Gtk::SpinButton m_spin_high_number;
 
         Gtk::HBox m_hbox_hour;
         Gtk::Label m_label_hour;
