@@ -97,7 +97,7 @@ bool ConfigItems::load( const bool restore )
     ref_prefix = cf.get_option_str( "ref_prefix", CONF_REF_PREFIX, 16 );
 
     // 参照文字( ref_prefix ) の後のスペースの数
-    // JDLIB::ConfLoader の中で MISC::remove_space() が呼ばれて空白が消えるので別設定とした
+    // JDLIB::ConfLoader の中で MISC::utf8_trim() が呼ばれて空白が消えるので別設定とした
     ref_prefix_space = cf.get_option_int( "ref_prefix_space", CONF_REF_PREFIX_SPACE, 0, 16 );
     for( int i = 0; i < ref_prefix_space; ++i ) ref_prefix_space_str += " ";
 
@@ -562,6 +562,9 @@ bool ConfigItems::load( const bool restore )
     // 状態変更時にメインステータスバーの色を変える
     change_stastatus_color = cf.get_option_bool( "change_stastatus_color", CONF_CHANGE_STASTATUS_COLOR );
 
+    // 状態変更時にスレビュータイトルの色を変える
+    change_statitle_color = cf.get_option_bool( "change_statitle_color", CONF_CHANGE_STATITLE_COLOR );
+
     // Client-Side Decorationを使うか( 0: 使わない 1: 使う 2: デスクトップに合わせる )
     use_header_bar = cf.get_option_int( "use_header_bar", CONF_USE_HEADER_BAR, 0, 2 );
 
@@ -588,6 +591,9 @@ bool ConfigItems::load( const bool restore )
     migemodict_path = cf.get_option_str( "migemodict_path", CONF_MIGEMO_PATH );
 #endif
 
+    // 不正な数値文字参照(サロゲートペア)をデコードする
+    correct_character_reference = cf.get_option_bool( "correct_character_reference", CONF_CORRECT_CHAR_REFERENCE );
+
     m_loaded = true;
 
     // 設定値に壊れている物がある
@@ -917,6 +923,7 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "disable_close", disable_close );
     cf.update( "show_hide_menubar_diag", show_hide_menubar_diag );
     cf.update( "change_stastatus_color", change_stastatus_color );
+    cf.update( "change_statitle_color", change_statitle_color );
     cf.update( "use_header_bar", use_header_bar );
     cf.update( "use_machi_offlaw", use_machi_offlaw );
     cf.update( "show_del_written_thread_diag", show_del_written_thread_diag );
@@ -929,6 +936,8 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "migemodict_path", migemodict_path );
 #endif
 
+    cf.update( "correct_character_reference", correct_character_reference );
+
     cf.save();
 }
 
