@@ -583,6 +583,9 @@ namespace CONFIG
     // 状態変更時にメインステータスバーの色を変える
     bool get_change_stastatus_color();
 
+    // 状態変更時にスレビュータイトルの色を変える
+    bool get_change_statitle_color();
+
     // Client-Side Decorationを使うか( 0: 使わない 1: 使う 2: デスクトップに合わせる )
     int get_use_header_bar();
 
@@ -613,6 +616,10 @@ namespace CONFIG
     // migemo-dictの場所
     const std::string& get_migemodict_path();
 #endif
+
+    // 不正な数値文字参照(サロゲートペア)をデコードする
+    bool get_correct_character_reference();
+    void set_correct_character_reference( const bool set );
 }
 
 
