@@ -11,6 +11,9 @@
 
 #include "control.h"
 
+#include <memory>
+
+
 namespace CONTROL
 {
     enum
@@ -48,9 +51,9 @@ namespace CONTROL
 
         int get_id() const { return m_id; }
 
-        std::string get_key_label();
-        std::string get_mouse_label();
-        std::string get_button_label();
+        std::string get_key_label() const;
+        std::string get_mouse_label() const;
+        std::string get_button_label() const;
 
       private:
 
@@ -84,7 +87,7 @@ namespace CONTROL
     {
         int m_id;
         int m_controlmode;
-        bool m_single;
+        bool m_single{};
 
         SKELETON::JDTreeViewBase m_treeview;
         Glib::RefPtr< Gtk::ListStore > m_liststore;
@@ -116,7 +119,7 @@ namespace CONTROL
         int get_single() const { return m_single; }
         void set_single( bool single ){ m_single = single; }
 
-        virtual InputDiag* create_inputdiag() = 0;
+        virtual std::unique_ptr<InputDiag> create_inputdiag() = 0;
         virtual std::string get_default_motions( const int id ) = 0;
         virtual std::vector< int > check_conflict( const int mode, const std::string& str_motion ) = 0;
 
@@ -190,7 +193,7 @@ namespace CONTROL
         void append_row( const int id, const std::string& label = std::string() );
         void append_comment_row( const std::string& comment );
 
-        virtual MouseKeyDiag* create_setting_diag( const int id, const std::string& str_motions ) = 0;
+        virtual std::unique_ptr<MouseKeyDiag> create_setting_diag( const int id, const std::string& str_motions ) = 0;
         virtual std::string get_str_motions( const int id ) = 0;
         virtual std::string get_default_motions( const int id ) = 0;
         virtual void set_motions( const int id, const std::string& str_motions ) = 0;
