@@ -201,6 +201,16 @@ void Css_Manager::set_default_css()
     css.border_bottom_width_px = 1;
 
     set_property( "imgpopup", css );
+
+
+    /////////////////
+    // mark
+    std::map< std::string, std::string > props{
+        { "color", "black" },
+        { "background-color", "yellow" },
+    };
+
+    set_property( "mark", create_property( props ) );
 }
 
 
@@ -233,7 +243,7 @@ bool Css_Manager::read_css()
             ( r_pos = css_data.find( '}', l_pos + 1 ) ) != std::string::npos )
     {
         // セレクタ部分を取り出す
-        std::string selector = MISC::remove_spaces( css_data.substr( start_pos, l_pos - start_pos ) );
+        std::string selector = MISC::ascii_trim( css_data.substr( start_pos, l_pos - start_pos ) );
         start_pos = r_pos + 1;
         if( selector.rfind( '.', 0 ) == 0 ) selector.erase( 0, 1 );
         if( selector.empty() ) break;
@@ -250,20 +260,16 @@ bool Css_Manager::read_css()
 
         // プロパティペア(名前, 値)の作成
         std::map< std::string, std::string > css_pair;
-        std::list< std::string >::iterator it = properties.begin();
-        while( it != properties.end() )
-        {
-            size_t colon = (*it).find( ':' );
-            std::string key = MISC::remove_spaces( (*it).substr( 0, colon ) );
-            std::string value = MISC::remove_spaces( (*it).substr( colon + 1 ) );
+        for( const std::string& prop : properties ) {
+            const std::size_t colon = prop.find( ':' );
+            std::string key = MISC::ascii_trim( prop.substr( 0, colon ) );
+            std::string value = MISC::ascii_trim( prop.substr( colon + 1 ) );
 
 #ifdef _DEBUG
             std::cout << "  key = " << key << " value = " << value << std::endl;
 #endif
 
-            css_pair.insert( make_pair( key, value ) );
-
-            ++it;
+            css_pair.emplace( std::move( key ), std::move( value ) );
         }
 
         // 各プロパティを作成
@@ -745,7 +751,7 @@ bool Css_Manager::read_html()
             block = block.substr( pos );
         }
 
-        block = MISC::remove_space( MISC::tolower_str( block.substr( 1 ) ) );
+        block = MISC::utf8_trim( MISC::tolower_str( block.substr( 1 ) ) );
 
 #ifdef _DEBUG
         std::cout << "tag = " << block << std::endl;
