@@ -22,16 +22,10 @@ namespace DBTREE
         std::string create_write_message( const std::string& name, const std::string& mail,
                                           const std::string& msg ) override;
 
-        // bbscgi のURL
-        std::string url_bbscgi() override;
-        
-        // subbbscgi のURL
-        std::string url_subbbscgi() override;
-
       protected:
 
         // dat落ちしたスレをロードするか
-        bool is_load_olddat() override;
+        bool is_load_olddat() const override;
 
       private:
         
