@@ -23,10 +23,10 @@ namespace DBTREE
                                           const std::string& msg ) override;
 
         // bbscgi のURL
-        std::string url_bbscgi() override;
-        
+        std::string url_bbscgi() const override;
+
         // subbbscgi のURL
-        std::string url_subbbscgi() override;
+        std::string url_subbbscgi() const override;
 
       private:
         
