@@ -19,11 +19,12 @@
 
 #include "config/globalconf.h"
 
-#include "httpcode.h"
-#include "command.h"
 #include "cache.h"
+#include "command.h"
 #include "global.h"
+#include "httpcode.h"
 #include "login2ch.h"
+#include "replacestrmanager.h"
 #include "session.h"
 #include "updatemanager.h"
 
@@ -140,6 +141,16 @@ size_t ArticleBase::get_lng_dat()
 }
 
 
+/**
+ * @brief スレの最大DATサイズ(KB)
+ */
+std::size_t ArticleBase::get_dat_volume_max() const
+{
+    if( ! m_nodetree ) return 0;
+    return m_nodetree->get_dat_volume_max();
+}
+
+
 
 //
 // nodetree の number 番のレスのヘッダノードのポインタを返す
@@ -423,25 +434,43 @@ void ArticleBase::reset_status()
 }
 
 
+/** @brief 置換文字列を適用したスレタイトルを返す
+ *
+ * @details
+ * 置換したスレタイトルはキャッシュされて再び呼び出されたときに返す。
+ * @param[in] renew true のときキャッシュの有無に関係なく置換文字列を適用して更新する
+ */
+const std::string& ArticleBase::get_modified_subject( const bool renew )
+{
+    if( renew || m_modified_subject.empty() ){
+        const CORE::ReplaceStr_Manager* const mgr = CORE::get_replacestr_manager();
+
+        // タイトル文字列置換
+        if( mgr->list_get_active( CORE::REPLACETARGET_SUBJECT ) ){
+            m_modified_subject = mgr->replace( m_subject, CORE::REPLACETARGET_SUBJECT );
+        }
+        else m_modified_subject = m_subject;
+
+    }
+
+    return m_modified_subject;
+}
+
+
 void ArticleBase::set_subject( const std::string& subject )
 {
     if( subject.empty() ) return;
 
-    // 特殊文字の置き換え
-    if( subject.find( '&' ) != std::string::npos ){
+    std::string tmp_subject = MISC::ascii_trim( subject );
 
-        std::string subject_tmp = MISC::html_unescape( subject );
-
-        if( subject_tmp != m_subject ){
-            m_subject = subject_tmp;
-            m_save_info = true;
-        }
-    }
-    else if( subject != m_subject ){
-
-        m_subject = subject;
+    if( tmp_subject != m_subject ){
+        m_subject = std::move( tmp_subject );
         m_save_info = true;
     }
+
+    // 置換設定に変更がある場合も読み直すのでm_subjectが同じでも
+    // 次に読み込まれる時に生成させる為にクリア
+    m_modified_subject.clear();
 }
 
 
@@ -465,7 +494,7 @@ void ArticleBase::set_number( const int number, const bool is_online )
     // subject.txt に示されたレス数よりも実際の取得数の方が多い
     else if( is_online && number < m_number ){
 #ifdef _DEBUG
-        std::cout << "ArticleBase::set_number : broken_subject " << get_subject() << " "
+        std::cout << "ArticleBase::set_number : broken_subject " << m_subject << " "
                   << number << " / " << m_number << std::endl;
 #endif
         m_status |= STATUS_BROKEN_SUBJECT;
@@ -488,6 +517,15 @@ void ArticleBase::set_number_seen( const int number_seen )
 }
 
 
+void ArticleBase::set_number_max( const int number_max )
+{
+    if( number_max != m_number_max ){
+        m_number_max = number_max;
+        m_save_info = true;
+    }
+}
+
+
 // 最終書き込み時間( string型 )
 const std::string& ArticleBase::get_write_date()
 {
@@ -551,18 +589,21 @@ bool ArticleBase::enable_load() const
 }
 
 
-//
-// キャッシュはあるが規定のレス数を越えていて、かつ全てのレスが既読
-//
+/**
+ * @brief キャッシュが新着がない状態で存在し、さらに規定の最大レス数を越えているか
+ */
 bool ArticleBase::is_finished() const
 {
-    if( is_cached() && ! enable_load() &&  m_number_max && get_number_seen() >= m_number_max ){
+    if( is_cached() && ! enable_load() ){
+        const int number_max{ m_number_max ? m_number_max : DBTREE::board_get_number_max_res( m_url ) };
+        if( number_max && m_number_load >= number_max ){
 
 #ifdef _DEBUG
-        std::cout << "ArticleBase::is_finished :  seen = " << get_number_seen() << " max = " << m_number_max << " : " << get_subject() << std::endl;
+            std::cout << "ArticleBase::is_finished :  load = " << m_number_load << " max = " << number_max
+                      << " : " << m_subject << std::endl;
 #endif
-
-        return true;
+            return true;
+        }
     }
 
     return false;
@@ -1158,6 +1199,9 @@ void ArticleBase::download_dat( const bool check_update )
         return;
     }
 
+    // キャッシュが新着がない状態で存在し、さらに規定の最大レス数を越えているならロードしない
+    if( is_finished() ) return;
+
 #ifdef _DEBUG
     std::cout << "start\n";
 #endif       
@@ -1261,6 +1305,13 @@ void ArticleBase::slot_node_updated()
         // スレの読み込み数更新
         m_number_load = m_nodetree->get_res_number();
 
+        // スレの最大レス数更新
+        if( m_number_max == 0 ) {
+            const int res_max = m_nodetree->get_res_number_max();
+            if( res_max > 0 ) m_number_max = res_max;
+            else if( res_max == 0 ) m_number_max = CONFIG::get_max_resnumber();
+        }
+
         // 対応するarticleビューを更新
         CORE::core_set_command( "update_article", m_url );
     }
@@ -1603,7 +1654,7 @@ void ArticleBase::delete_cache( const bool cache_only )
 
         if( m_bookmarked_thread ){
 
-            const std::string msg = "「" + get_subject() +
+            const std::string msg = "「" + MISC::to_plain( get_modified_subject() ) +
             "」にはしおりが付けられています。\n\nスレを削除しますか？\n\nしおりを解除するにはスレの上で右クリックしてしおり解除を選択してください。";
 
             SKELETON::MsgDiag mdiag( nullptr, msg, false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
@@ -1613,7 +1664,7 @@ void ArticleBase::delete_cache( const bool cache_only )
 
         if( CONFIG::get_show_del_written_thread_diag() && m_write_time ){
 
-            const std::string msg = "「" + get_subject() + "」には書き込み履歴が残っています。\n\nスレを削除しますか？";
+            const std::string msg = "「" + MISC::to_plain( get_modified_subject() ) + "」には書き込み履歴が残っています。\n\nスレを削除しますか？";
 
             SKELETON::MsgCheckDiag mdiag( nullptr, msg,
                                           "今後表示しない(常に削除)(_D)",
@@ -1635,7 +1686,7 @@ void ArticleBase::delete_cache( const bool cache_only )
 
                 if( CONFIG::get_delete_img_in_thread() == 0 ){
 
-                    const std::string msg = "「" + get_subject() + "」には画像が貼られています。\n\n画像のキャッシュも削除しますか？";
+                    const std::string msg = "「" + MISC::to_plain( get_modified_subject() ) + "」には画像が貼られています。\n\n画像のキャッシュも削除しますか？";
 
                     SKELETON::MsgCheckDiag mdiag( nullptr, msg,
                                                   "今後表示しない(常に削除しない)(_D)",
@@ -1797,6 +1848,7 @@ void ArticleBase::read_info()
 
         // subject
         GET_INFOVALUE( m_subject, "subject = " );
+        m_modified_subject.clear(); // 読み込まれる時に生成
 
         // 旧ホスト名
         GET_INFOVALUE( m_org_host, "org_host = " );
@@ -1813,6 +1865,11 @@ void ArticleBase::read_info()
         GET_INFOVALUE( str_tmp, "seen = " );
         if( ! str_tmp.empty() ) m_number_seen = std::stoi( str_tmp );
 
+        // 最大レス数
+        m_number_max = 0;
+        GET_INFOVALUE( str_tmp, "max = " );
+        if( ! str_tmp.empty() ) m_number_max = std::atoi( str_tmp.c_str() );
+
         // 更新時間 (time)
         GET_INFOVALUE( m_date_modified, "modified = " );
 
@@ -2025,6 +2082,7 @@ void ArticleBase::read_info()
               << "org_host = " << m_org_host << std::endl
               << "load = " << m_number_load << std::endl
               << "seen = " << m_number_seen << std::endl
+              << "max = " << m_number_max << std::endl
               << "modified = " << m_date_modified << std::endl
               << "writetime = " << m_write_time_date << std::endl
               << "writename = " << m_write_name << std::endl
@@ -2150,6 +2208,7 @@ void ArticleBase::save_info( const bool force )
          << "org_host = " << m_org_host << std::endl
          << "load = " << m_number_load << std::endl
          << "seen = " << m_number_seen << std::endl
+         << "max = " << m_number_max << std::endl
          << "modified = " << m_date_modified << std::endl
          << "access = " << get_access_time_str() << std::endl
          << "writetime = " << ss_write.str() << std::endl
