@@ -52,6 +52,7 @@ namespace DBTREE
         std::string m_org_host;
 
         std::string m_subject;           // サブジェクト
+        std::string m_modified_subject;  // 置換で変更されたサブジェクト
         int m_number{};                  // サーバ上にあるレスの数
         int m_number_diff{};             // レス増分( subject.txt をロードした時の m_number の増分 )
         int m_number_new{};              // 新着数( ロードした時の差分読み込み数)
@@ -143,13 +144,13 @@ namespace DBTREE
         const std::string& get_id() const { return m_id; }
         const std::string& get_key() const { return m_key; }
         const std::string& get_subject() const { return m_subject; }
+        const std::string& get_modified_subject( const bool renew = false );
         int get_number() const noexcept { return m_number; }
         int get_number_diff() const noexcept { return m_number_diff; }
         int get_number_new() const noexcept { return m_number_new; }
         int get_number_load() const noexcept { return m_number_load; }
         int get_number_seen() const noexcept {  return m_number_seen; }
-
-        void set_number_max( const int number ){ m_number_max = number; }
+        int get_number_max() const noexcept { return m_number_max; }
 
         // スレ速度
         int get_speed() const;
@@ -157,6 +158,9 @@ namespace DBTREE
         // キャッシュにあるdatファイルのサイズ
         size_t get_lng_dat();
 
+        // スレの最大DATサイズ(KB)
+        std::size_t get_dat_volume_max() const;
+
         // nodetree の number 番のレスのヘッダノードのポインタを返す
         NODE* res_header( int number );
 
@@ -292,6 +296,7 @@ namespace DBTREE
         void set_number( const int number, const bool is_online );
         void set_number_load( const int number_load );
         void set_number_seen( const int number_seen );
+        void set_number_max( const int number_max );
         void update_writetime();
 
         // キャッシュ削除
@@ -311,7 +316,7 @@ namespace DBTREE
         // キャッシュがあって、かつ新着の読み込みが可能
         bool enable_load() const;
 
-        // キャッシュはあるが規定のレス数を越えていて、かつ全てのレスが既読
+        // キャッシュが新着がない状態で存在し、さらに規定の最大レス数を越えているか
         bool is_finished() const;
 
         // あぼーん情報
@@ -412,6 +417,9 @@ namespace DBTREE
         // スレッド924か
         bool is_924() const noexcept { return m_924; }
 
+        // NodeTree削除
+        void unlock_impl() override;
+
       private:
 
         // 更新チェック可能
@@ -427,7 +435,6 @@ namespace DBTREE
 
         void slot_node_updated();
         void slot_load_finished();
-        void unlock_impl() override;
 
         // お気に入りのアイコンとスレビューのタブのアイコンに更新マークを表示
         // update == true の時に表示。falseなら戻す
