@@ -274,6 +274,18 @@ std::string Board2ch::url_subbbscgi_new() const
 }
 
 
+/** @brief SETTING.TXT の項目 BBS_UNICODE の値を返す
+ *
+ * @remarks 2022-04-30 以降、5chでは BBS_UNICODE が無効になったため
+ * 設定値に関係なく空文字列を返すように変更する
+ */
+std::string Board2ch::get_unicode() const
+{
+    // XXX: "pass" のほうが適切な値か？
+    return {};
+}
+
+
 
 //
 // 新しくArticleBaseクラスを追加してそのポインタを返す
@@ -285,12 +297,8 @@ ArticleBase* Board2ch::append_article( const std::string& datbase, const std::st
     if( empty() ) return get_article_null();
 
     ArticleBase* article = insert( std::make_unique<DBTREE::Article2ch>( datbase, id, cached ) );
-    if( article ){
-        // 最大レス数セット
-        article->set_number_max( get_number_max_res() );
-    }
-    else return get_article_null();
 
+    if( ! article ) return get_article_null();
     return article;
 }
 
