@@ -139,7 +139,8 @@ namespace DBTREE
         std::list< std::string > m_list_abone_thread_remove; // あぼーんするスレのタイトル( dat 落ち判定用、remove_old_abone_thread()を参照せよ )
         std::list< std::string > m_list_abone_word_thread; // あぼーんする文字列
         std::list< std::string > m_list_abone_regex_thread; // あぼーんする正規表現
-        int m_abone_number_thread{}; // レスの数
+        int m_abone_low_number_thread{};  // nレス以下をあぼーんする
+        int m_abone_high_number_thread{}; // nレス以上をあぼーんする
         int m_abone_hour_thread{}; // スレ立てからの経過時間
 
         // 読み込み用ローカルプロキシ設定
@@ -209,6 +210,9 @@ namespace DBTREE
         // Null artice クラス
         std::unique_ptr<ArticleBase> m_article_null;
 
+        /// 板のユーザーエージェント設定 (空のときは全体設定を使う)
+        std::string m_board_agent;
+
       protected:
 
         ARTICLE_INFO_LIST& get_list_artinfo(){ return m_list_artinfo; }
@@ -468,7 +472,8 @@ namespace DBTREE
         const std::list< std::string >& get_abone_list_thread_remove(){ return m_list_abone_thread_remove; }
         const std::list< std::string >& get_abone_list_word_thread(){ return m_list_abone_word_thread; }
         const std::list< std::string >& get_abone_list_regex_thread(){ return m_list_abone_regex_thread; }
-        int get_abone_number_thread() const noexcept { return m_abone_number_thread; }
+        int get_abone_low_number_thread() const noexcept { return m_abone_low_number_thread; }
+        int get_abone_high_number_thread() const noexcept { return m_abone_high_number_thread; }
         int get_abone_hour_thread() const noexcept { return m_abone_hour_thread; }
 
         // subject.txtのロード後にdat落ちしたスレッドをスレあぼーんのリストから取り除く
@@ -484,7 +489,8 @@ namespace DBTREE
         void reset_abone_thread( const std::list< std::string >& threads,
                                  const std::list< std::string >& words,
                                  const std::list< std::string >& regexs,
-                                 const int number,
+                                 const int low_number,
+                                 const int high_number,
                                  const int hour,
                                  const bool redraw
             );
@@ -538,6 +544,10 @@ namespace DBTREE
         // 最終アクセス時刻
         time_t get_last_access_time() const{ return m_last_access_time; }
 
+        // 板のユーザーエージェント設定
+        const std::string& get_board_agent() const { return m_board_agent; }
+        void set_board_agent( const std::string& user_agent ) { m_board_agent = user_agent; }
+
         // 最大レス数
         int get_number_max_res() const { return m_number_max_res; }
         void set_number_max_res( const int number );
@@ -613,7 +623,8 @@ namespace DBTREE
 
         // レス数であぼーん(グローバル)
         // 2ch以外の板ではキャンセルする
-        virtual int get_abone_number_global() const { return 0; }
+        virtual int get_abone_low_number_global() const { return 0; }
+        virtual int get_abone_high_number_global() const { return 0; }
     };
 }
 
