@@ -928,11 +928,15 @@ std::string DBTREE::article_ext_err( const std::string& url )
     return DBTREE::get_article( url )->get_ext_err();
 }
 
-std::string DBTREE::article_subject( const std::string& url )
+const std::string& DBTREE::article_subject( const std::string& url )
 {
     return DBTREE::get_article( url )->get_subject();
 }
 
+const std::string& DBTREE::article_modified_subject( const std::string& url, const bool renew )
+{
+    return DBTREE::get_article( url )->get_modified_subject( renew );
+}
 
 int DBTREE::article_number( const std::string& url )
 {
@@ -959,6 +963,16 @@ int DBTREE::article_number_new( const std::string& url )
     return DBTREE::get_article( url )->get_number_new();
 }
 
+int DBTREE::article_number_max( const std::string& url )
+{
+    return DBTREE::get_article( url )->get_number_max();
+}
+
+void DBTREE::article_set_number_max( const std::string& url, int max )
+{
+    DBTREE::get_article( url )->set_number_max( max );
+}
+
 bool DBTREE::article_is_loading( const std::string& url )
 {
     return DBTREE::get_article( url )->is_loading();
@@ -996,6 +1010,12 @@ int DBTREE::article_get_speed( const std::string& url )
 }
 
 
+std::size_t DBTREE::article_get_dat_volume_max( const std::string& url )
+{
+    return DBTREE::get_article( url )->get_dat_volume_max();
+}
+
+
 // 書き込み履歴のリセット
 void DBTREE::article_clear_post_history( const std::string& url )
 {
@@ -1003,6 +1023,13 @@ void DBTREE::article_clear_post_history( const std::string& url )
 }
 
 
+// NodeTree削除
+void DBTREE::article_clear_nodetree( const std::string& url )
+{
+    DBTREE::get_article( url )->unlock_impl();
+}
+
+
 // ユーザーエージェント
 // ダウンロード用
 const std::string& DBTREE::get_agent( const std::string& url )
