@@ -227,12 +227,15 @@ namespace DBTREE
     int article_code( const std::string& url );
     std::string article_str_code( const std::string& url );
     std::string article_ext_err( const std::string& url );
-    std::string article_subject( const std::string& url );
+    const std::string& article_subject( const std::string& url );
+    const std::string& article_modified_subject( const std::string& url, const bool renew = false );
     int article_number( const std::string& url );
     int article_number_load( const std::string& url );
     int article_number_seen( const std::string& url );
     void article_set_number_seen( const std::string& url, int seen );
     int article_number_new( const std::string& url );
+    int article_number_max( const std::string& url );
+    void article_set_number_max( const std::string& url, int max );
     bool article_is_loading( const std::string& url );
     bool article_is_checking_update( const std::string& url );
     void article_download_dat( const std::string& url, const bool check_update );
@@ -240,6 +243,7 @@ namespace DBTREE
     void article_copy_article_info( const std::string& url, const std::string& url_src );
     void article_stop_load( const std::string& url );
     int article_get_speed( const std::string& url );
+    std::size_t article_get_dat_volume_max( const std::string& url );
 
     // 書き込み履歴のリセット
     void article_clear_post_history( const std::string& url );
@@ -257,6 +261,9 @@ namespace DBTREE
     void article_update_writetime( const std::string& url );
     size_t article_lng_dat( const std::string& url );
 
+    // NodeTree削除
+    void article_clear_nodetree( const std::string& url );
+
     // ユーザーエージェント
     const std::string& get_agent( const std::string& url );   // ダウンロード用
     const std::string& get_agent_w( const std::string& url ); // 書き込み用
