@@ -13,11 +13,10 @@
 #include "skeleton/loadable.h"
 
 #include "jdlib/heap.h"
-#include "jdlib/miscutil.h"
 #include "jdlib/jdregex.h"
 
 #include <map>
-#include <cstring>
+#include <string_view>
 #include <unordered_map>
 #include <unordered_set>
 
@@ -164,6 +163,10 @@ namespace DBTREE
         const std::string& get_ext_err() const { return m_ext_err; }
         bool is_checking_update() const { return m_check_update; }
 
+        virtual int get_res_number_max() const noexcept { return -1; }
+        // スレの最大DATサイズ(KB)
+        virtual std::size_t get_dat_volume_max() const noexcept { return 0; }
+
         // number番のレスのヘッダノードのポインタを返す
         const NODE* res_header( int number ) const;
         NODE* res_header( int number )
@@ -292,6 +295,9 @@ namespace DBTREE
         void receive_data( const char* data, size_t size ) override;
         void receive_finish() override;
 
+        // 拡張属性を取り出す
+        virtual void parse_extattr( std::string_view str ) {};
+
       private:
 
         NODE* create_node();
@@ -301,45 +307,45 @@ namespace DBTREE
         NODE* create_node_br();
         NODE* create_node_hr();
         NODE* create_node_space( const int type );
-        NODE* create_node_multispace( const char* text, const int n, const char fontid = FONT_MAIN );
+        NODE* create_node_multispace( std::string_view text, const char fontid = FONT_MAIN );
         NODE* create_node_htab();
-        NODE* create_node_link( const char* text, const int n, const char* link, const int n_link, const int color_text, const bool bold, const char fontid = FONT_MAIN );
-        NODE* create_node_anc( const char* text, const int n, const char* link, const int n_link,
+        NODE* create_node_link( std::string_view text, std::string_view link,
+                                const int color_text, const bool bold, const char fontid = FONT_MAIN );
+        NODE* create_node_anc( std::string_view text, std::string_view link,
                                const int color_text, const bool bold,
                                const ANCINFO* ancinfo, const int lng_ancinfo, const char fontid = FONT_MAIN );
-        NODE* create_node_sssp( const char* link, const int n_link );
-        NODE* create_node_img( const char* text, const int n, const char* link, const int n_link, const int color_text,
+        NODE* create_node_sssp( std::string_view link );
+        NODE* create_node_img( std::string_view text, std::string_view link, const int color_text,
                                const bool bold, const char fontid = FONT_MAIN );
-        NODE* create_node_text( const char* text, const int color_text, const bool bold = false, const char fontid = FONT_MAIN );
+        NODE* create_node_text( std::string_view text, const int color_text, const bool bold = false, const char fontid = FONT_MAIN );
         NODE* create_node_ntext( const char* text, const int n, const int color_text, const bool bold = false, const char fontid = FONT_MAIN );
-        NODE* create_node_thumbnail( const char* text, const int n, const char* link, const int n_link, const char* thumb, const int n_thumb,
+        NODE* create_node_thumbnail( std::string_view text, std::string_view link, std::string_view thumb,
                                      const int color_text, const bool bold, const char fontid = FONT_MAIN );
 
         // 以下、構文解析用関数
         void add_raw_lines( char* rawines, size_t size );
         const char* add_one_dat_line( const char* datline );
 
-        void parse_name( NODE* header, const char* str, const int lng, const int color_name );
-        void parse_mail( NODE* header, const char* str, const int lng );
-        void parse_date_id( NODE* header, const char* str, const int lng );
+        void parse_name( NODE* header, std::string_view str, const int color_name );
+        void parse_mail( NODE* header, std::string_view str );
+        void parse_date_id( NODE* header, std::string_view str );
 
         // HTMLパーサ
         // digitlink : true の時は先頭に数字が現れたらアンカーにする( parse_name() などで使う )
         //             false なら数字の前に >> がついてるときだけアンカーにする
         // bold : ボールド表示
         // ahref : <a href=～></a> からリンクノードを作成する
-        void parse_html( const char* str, const int lng, const int color_text,
+        void parse_html( std::string_view str, const int color_text,
                          bool digitlink, const bool bold, const bool ahref, const char fontid = FONT_MAIN );
 
         // 書き込みログ比較用文字列作成
         // m_buffer_write に作成した文字列をセットする
-        void parse_write( const char* str, const int lng, const std::size_t max_lng_write );
+        void parse_write( std::string_view str, const std::size_t max_lng_write );
 
         bool check_anchor( const int mode, const char* str_in, int& n, char* str_out, char* str_link, int lng_link,
                            ANCINFO* ancinfo ) const;
+        /// リンクが現れたかチェックして文字列を取得する関数
         int check_link( const char* str_in, const int lng_in, int& n_in, char* str_link, const int lng_link ) const;
-        int check_link_impl( const char* str_in, const int lng_in, int& n_in, char* str_link, const int lng_link,
-                             const int linktype, const int delim_pos ) const;
 
         // レジューム時のチェックデータをキャッシュ
         void set_resume_data( const char* data, size_t length );
@@ -395,30 +401,13 @@ namespace DBTREE
         // number番のレスのフォント判定を更新
         void check_fontid( const int number );
 
-
+      public:
         // http://ime.nu/ などをリンクから削除
         static bool remove_imenu( char* str_link );
 
         // 文字列中の"&amp;"を"&"に変換する
         static int convert_amp( char* text, const int n );
     };
-
-
-    //
-    // リンクが現れたかチェックして文字列を取得する関数
-    //   (引数の値は、check_link_impl()を見ること)
-    //
-    inline int NodeTreeBase::check_link( const char* str_in, const int lng_in, int& n_in, char* str_link,
-                                         const int lng_link ) const
-    {
-        // http://, https://, ftp://, ttp(s)://, tp(s):// のチェック
-        int delim_pos = 0;
-        const int linktype = MISC::is_url_scheme( str_in, &delim_pos );
-
-        if( linktype == MISC::SCHEME_NONE ) return linktype;
-
-        return check_link_impl( str_in, lng_in, n_in, str_link, lng_link, linktype, delim_pos );
-    }
 }
 
 #endif
