@@ -11,10 +11,11 @@
 #include "cache.h"
 #include "jdlib/miscmsg.h"
 
-#include <fcntl.h>
-#include <errno.h>
 #include <cstring>
+#include <errno.h>
+#include <fcntl.h>
 #include <sys/stat.h>
+#include <unistd.h>
 
 
 using namespace CORE;
@@ -30,7 +31,6 @@ IOMonitor::IOMonitor()
     , m_fifo_file( CACHE::path_lock() )
     , m_fifo_stat( FIFO_OK )
 {
-    init();
 }
 
 
@@ -49,7 +49,7 @@ IOMonitor::~IOMonitor()
 /*-------------------------------------------------------------------*/
 // このクラスの初期化( FIFO作成、FIFOオープン、Glib::IOChannelの作成 )
 /*-------------------------------------------------------------------*/
-void IOMonitor::init()
+void IOMonitor::init_connection()
 {
     // 既にFIFOと同名のファイルが存在するか確認
     const int status = CACHE::file_exists( m_fifo_file );
@@ -118,7 +118,7 @@ void IOMonitor::init()
         m_main_process = true;
 
         // Glib::IOChannel
-        Glib::signal_io().connect( sigc::mem_fun( this, &IOMonitor::slot_ioin ), m_fifo_fd, Glib::IO_IN );
+        Glib::signal_io().connect( sigc::mem_fun( *this, &IOMonitor::slot_ioin ), m_fifo_fd, Glib::IO_IN );
         m_iochannel = Glib::IOChannel::create_from_fd( m_fifo_fd );
     }
 }
@@ -147,21 +147,15 @@ void IOMonitor::delete_fifo()
 //
 // 戻り値: 全て書き込まれたか否か
 /*-------------------------------------------------------------------*/
-bool IOMonitor::send_command( const char* command )
+bool IOMonitor::send_command( const std::string& command )
 {
-    if( ! command ) return false;
-
-    const size_t command_length = strlen( command );
-
     // 異常に長かったら書き込まない
-    if( command_length > COMMAND_MAX_LENGTH ) return false;
+    if( command.size() > COMMAND_MAX_LENGTH ) return false;
 
     g_assert( m_fifo_fd >= 0 );
 
-    int status = -1;
-    status = write( m_fifo_fd, command, command_length );
-
-    return ( (size_t)status == command_length );
+    const ssize_t status = write( m_fifo_fd, command.c_str(), command.size() );
+    return static_cast<std::size_t>( status ) == command.size();
 }
 
 
@@ -188,11 +182,6 @@ bool IOMonitor::slot_ioin( Glib::IOCondition io_condition )
         MISC::ERRMSG( "IOMonitor::slot_ioin(): read error." );
     }
 
-#ifdef _DEBUG
-    std::cout << "入力文字: " << buffer << std::endl;
-    if( buffer == "Q" ) Gtk::Main::quit();
-#endif // _DEBUG
-
     // FIFOに書き込まれたURLを開く
     // "現在のタブ/新しいタブ"など、開き方を選ぶ必要があるかも知れない
     //core_set_command( "open_article", buffer, "left", "auto" );
