@@ -5,13 +5,13 @@
 #include "jddebug.h"
 
 #include "jdiconv.h"
+#include "misccharcode.h"
 #include "miscmsg.h"
-#include "miscutil.h"
 
-#include <errno.h>
-#include <cstring>
+#include <algorithm>
 #include <cstdio>
-#include <cstdlib>
+#include <cstring>
+#include <errno.h>
 
 
 using namespace JDLIB;
@@ -22,9 +22,9 @@ Iconv::Iconv( const std::string& coding_to, const std::string& coding_from )
 #ifdef _DEBUG
     std::cout << "Iconv::Iconv coding = " << m_coding_from << " to " << coding_to << std::endl;
 #endif
-    
-    m_buf_in = ( char* )malloc( BUF_SIZE_ICONV_IN );
-    m_buf_out = ( char* )malloc( BUF_SIZE_ICONV_OUT );
+
+    m_buf_in.reserve( BUF_SIZE_ICONV_IN );
+    m_buf_out.resize( BUF_SIZE_ICONV_OUT );
     
     m_cd = g_iconv_open( coding_to.c_str(), m_coding_from.c_str() );
 
@@ -59,8 +59,6 @@ Iconv::~Iconv()
     std::cout << "Iconv::~Iconv\n";
 #endif    
     
-    if( m_buf_in ) free( m_buf_in );
-    if( m_buf_out ) free( m_buf_out );
     if( m_cd != ( GIConv ) -1 ) g_iconv_close( m_cd );
 }
 
@@ -76,13 +74,14 @@ const char* Iconv::convert( char* str_in, int size_in, int& size_out )
     if( m_cd == ( GIConv ) -1 ) return nullptr;
     
     size_t byte_left_out = BUF_SIZE_ICONV_OUT;
-    char* buf_out = m_buf_out;
+    char* buf_out = m_buf_out.data();
 
     // 前回の残りをコピー
     if( m_byte_left_in ){
-        memcpy( m_buf_in, m_buf_in_tmp, m_byte_left_in );
-        m_buf_in_tmp = m_buf_in;
-        memcpy( m_buf_in + m_byte_left_in , str_in, size_in );    
+        m_buf_in.clear();
+        std::copy_n( m_buf_in_tmp, m_byte_left_in, std::back_inserter( m_buf_in ) );
+        std::copy_n( str_in, size_in, std::back_inserter( m_buf_in ) );
+        m_buf_in_tmp = m_buf_in.data();
     }
     else m_buf_in_tmp = str_in;
 
@@ -168,34 +167,35 @@ const char* Iconv::convert( char* str_in, int size_in, int& size_out )
 
                     for ( ; ; ) {
                         int byte;
-                        const int ucs2 = MISC::utf8toucs2( m_buf_in_tmp, byte );
+                        const char32_t unich = MISC::utf8toutf32( m_buf_in_tmp, byte );
                         if( byte <= 1 ) break;
 
                         // emoji subdivision flags の処理
                         if ( is_handling_emoji_subdivision_flag ) {
                             // Tag Latin Small Letterの範囲か、Cancel Tagでなければ、処理中断
                             if ( byte != 4 ) break;
-                            if ( ucs2 < 917601 ) break; // U+E0061 TAG LATIN SMALL LETTER A
-                            if ( ucs2 > 917631 ) break; // U+E007F CANCEL TAG
+                            if ( unich < 917601 ) break; // U+E0061 TAG LATIN SMALL LETTER A
+                            if ( unich > 917631 ) break; // U+E007F CANCEL TAG
                         }
 
-                        const std::string ucs2_str = std::to_string( ucs2 );
+                        const std::string uni_str = std::to_string( unich );
 #ifdef _DEBUG
-                        std::cout << "ucs2 = " << ucs2_str << " byte = " << byte << std::endl;
+                        std::cout << "utf32 = " << unich << " byte = " << byte << std::endl;
 #endif
                         m_buf_in_tmp += byte;
                         m_byte_left_in -= byte;
 
                         *(buf_out++) = '&';
                         *(buf_out++) = '#';
-                        memcpy( buf_out, ucs2_str.c_str(), ucs2_str.size() ); buf_out += ucs2_str.size();
+                        memcpy( buf_out, uni_str.c_str(), uni_str.size() );
+                        buf_out += uni_str.size();
                         *(buf_out++) = ';';
 
-                        byte_left_out -= ucs2_str.size() + 3;
+                        byte_left_out -= uni_str.size() + 3;
                         is_converted_to_ucs2 = true;  // 一度変換されたのでマーク
 
                         if ( ! is_handling_emoji_subdivision_flag ) {
-                            if ( ( byte == 4 ) && ( ucs2 == 127988 ) ){ // U+1F3F4 WAVING BLACK FLAG
+                            if ( ( byte == 4 ) && ( unich == 127988 ) ){ // U+1F3F4 WAVING BLACK FLAG
                                 // emoji subdivision flags の処理開始
                                 is_handling_emoji_subdivision_flag = true;
                                 continue; // 連続処理
@@ -244,5 +244,5 @@ const char* Iconv::convert( char* str_in, int size_in, int& size_out )
     size_out = BUF_SIZE_ICONV_OUT - byte_left_out;
     m_buf_out[ size_out ] = '\0';
     
-    return m_buf_out;
+    return m_buf_out.data();
 }
