@@ -12,17 +12,14 @@
 
 
 constexpr std::size_t MAX_TARGET_SIZE = 64 * 1024;  // 全角半角変換のバッファサイズ
-#ifdef POSIX_STYLE_REGEX_API
-constexpr std::size_t REGEX_MAX_NMATCH = 32;
-#endif
 
 
 using namespace JDLIB;
 
 RegexPattern::RegexPattern( const std::string& reg, const bool icase, const bool newline,
-                            const bool usemigemo, const bool wchar )
+                            const bool usemigemo, const bool wchar, const bool norm )
 {
-    set( reg, icase, newline, usemigemo, wchar );
+    set( reg, icase, newline, usemigemo, wchar, norm );
 }
 
 
@@ -37,6 +34,7 @@ RegexPattern::RegexPattern( RegexPattern&& other ) noexcept
     , m_compiled{ other.m_compiled }
     , m_newline{ other.m_newline }
     , m_wchar{ other.m_wchar }
+    , m_norm{ other.m_norm }
     , m_error{ other.m_error }
 {
     other.m_compiled = false;
@@ -53,6 +51,7 @@ RegexPattern& RegexPattern::operator=( RegexPattern&& other ) noexcept
         m_compiled = other.m_compiled;
         m_newline = other.m_newline;
         m_wchar = other.m_wchar;
+        m_norm = other.m_norm;
         m_error = other.m_error;
 
         other.m_compiled = false;
@@ -65,28 +64,28 @@ RegexPattern& RegexPattern::operator=( RegexPattern&& other ) noexcept
 void RegexPattern::clear()
 {
     if ( m_compiled ) {
-#ifdef POSIX_STYLE_REGEX_API
-        regfree( &m_regex );
-#else
         g_regex_unref( m_regex );
         m_regex = nullptr;
-#endif
     }
     m_compiled = false;
-
-#ifdef POSIX_STYLE_REGEX_API
-    m_error = 0;
-#else
     g_clear_error( &m_error );
-#endif
 }
 
-// icase : 大文字小文字区別しない
-// newline :  . に改行をマッチさせない
-// usemigemo : migemo使用 (コンパイルオプションで指定する必要あり)
-// wchar : 全角半角の区別をしない
+
+/** @brief 正規表現パターンを設定する
+ *
+ * @details 空文字列のパターンは作成しない。
+ * @param[in] reg       正規表現パターン
+ * @param[in] icase     大文字小文字の区別をしない
+ * @param[in] newline   `.`(任意の1文字)に改行をマッチさせない
+ * @param[in] usemigemo migemo使用 (コンパイルオプションで指定する必要あり)
+ * @param[in] wchar     全角半角の区別をしない
+ * @param[in] norm      Unicode互換文字の区別をしない
+ * @return 有効な正規表現パターンはtrue、無効なパターンはfalse
+ * @n reg が空文字列のときはfalse
+ */
 bool RegexPattern::set( const std::string& reg, const bool icase, const bool newline,
-                        const bool usemigemo, const bool wchar )
+                        const bool usemigemo, const bool wchar, const bool norm )
 {
 #ifdef _DEBUG
     if( wchar ){
@@ -98,25 +97,27 @@ bool RegexPattern::set( const std::string& reg, const bool icase, const bool new
 
     if( reg.empty() ) return false;
 
-#ifdef POSIX_STYLE_REGEX_API
-    int cflags = REG_EXTENDED;
-    if( newline ) cflags |= REG_NEWLINE;
-    if( icase ) cflags |= REG_ICASE;
-#else
     int cflags = G_REGEX_OPTIMIZE;
     if( newline ) cflags |= G_REGEX_MULTILINE;
     else cflags |= G_REGEX_DOTALL; // . を改行にマッチさせる
     if( icase ) cflags |= G_REGEX_CASELESS;
-#endif // POSIX_STYLE_REGEX_API
 
     m_newline = newline;
     m_wchar = wchar;
+    m_norm = norm;
 
     const char* asc_reg = reg.c_str();
     std::string target_asc;
 
+    // Unicode正規化
+    if( m_norm ) {
+        target_asc.reserve( reg.size() * 2 );
+        MISC::norm( asc_reg, target_asc );
+        asc_reg = target_asc.c_str();
+    }
+
     // 全角英数字 → 半角英数字、半角カナ → 全角カナ
-    if( m_wchar && MISC::has_widechar( asc_reg ) ){
+    else if( m_wchar && MISC::has_widechar( asc_reg ) ) {
 
         target_asc.reserve( MAX_TARGET_SIZE );
         std::vector<int> temp;
@@ -140,18 +141,10 @@ bool RegexPattern::set( const std::string& reg, const bool icase, const bool new
     }
 #endif
 
-#ifdef POSIX_STYLE_REGEX_API
-    m_error = regcomp( &m_regex, asc_reg, cflags );
-    if( m_error != 0 ) {
-        regfree( &m_regex );
-        return false;
-    }
-#else
     m_regex = g_regex_new( asc_reg, GRegexCompileFlags( cflags ), GRegexMatchFlags( 0 ), &m_error );
     if( ! m_regex ) {
         return false;
     }
-#endif
 
     m_compiled = true;
     return true;
@@ -162,31 +155,9 @@ std::string RegexPattern::errstr() const
 {
     std::string errmsg;
 
-#ifdef POSIX_STYLE_REGEX_API
-    switch( m_error ) {
-        case 0: errmsg = "エラーはありません。"; break;
-        case REG_BADBR: errmsg = "無効な後方参照オペレータを使用しています。"; break;
-        case REG_BADPAT: errmsg = "無効なグループやリストなどを使用しています。"; break;
-        case REG_BADRPT: errmsg = "'*' が最初の文字としてくるような、無効な繰り返しオペレータを使用しています。"; break;
-        case REG_EBRACE: errmsg = "インターバルオペレータ {} が閉じていません。"; break;
-        case REG_EBRACK: errmsg = "リストオペレータ [] が閉じていません。"; break;
-        case REG_ECOLLATE: errmsg = "照合順序の要素として有効ではありません。"; break;
-        case REG_ECTYPE: errmsg = "未知のキャラクタークラス名です。"; break;
-        case REG_EESCAPE: errmsg = "正規表現がバックスラッシュで終っています。"; break;
-        case REG_EPAREN: errmsg = "グループオペレータ () が閉じていません。"; break;
-        case REG_ERANGE: errmsg = "無効な範囲オペレータを使用しています。"; break;
-#ifndef HAVE_ONIGPOSIX_H
-        case REG_ESIZE: errmsg = "複雑過ぎる正規表現です。POSIX.2 には定義されていません。"; break;
-#endif
-        case REG_ESPACE: errmsg = "regex ルーチンがメモリーを使い果たしました。"; break;
-        case REG_ESUBREG: errmsg = "サブエクスプレッション (...) への無効な後方参照です。"; break;
-        default: errmsg = "未知のエラーが発生しました。"; break;
-    }
-#else
     if( m_error ) {
         errmsg = m_error->message;
     }
-#endif
     return errmsg;
 }
 
@@ -209,8 +180,18 @@ bool Regex::match( const RegexPattern& creg, const std::string& target,
 
     const char* asc_target = target.c_str() + offset;
 
+    // Unicode正規化
+    if( creg.m_norm ) {
+        if( m_target_asc.capacity() < target.size() * 2 ) {
+            m_target_asc.reserve( target.size() * 2 );
+            m_table_pos.reserve( target.size() * 2 );
+        }
+        MISC::norm( asc_target, m_target_asc, &m_table_pos );
+        asc_target = m_target_asc.c_str();
+    }
+
     // 全角英数字 → 半角英数字、半角カナ → 全角カナ
-    if( creg.m_wchar && MISC::has_widechar( asc_target ) ) {
+    else if( creg.m_wchar && MISC::has_widechar( asc_target ) ) {
 
 #ifdef _DEBUG
         std::cout << "Regex::match offset = " << offset << std::endl;
@@ -230,55 +211,23 @@ bool Regex::match( const RegexPattern& creg, const std::string& target,
 #endif
     }
 
-#ifdef HAVE_ONIGPOSIX_H
-    std::string target_copy;
-
-    // 鬼車はnewlineを無視するようなので、文字列のコピーを取って
-    // 改行をスペースにしてから実行する
-    if( ! creg.m_newline ) {
-        target_copy = asc_target;
-        std::replace( target_copy.begin(), target_copy.end(), '\n', ' ' );
-        asc_target = target_copy.c_str();
-    }
-#endif
-
-#ifdef POSIX_STYLE_REGEX_API
-    regmatch_t pmatch[ REGEX_MAX_NMATCH ]{};
-
-    int eflags = 0;
-    if( notbol ) eflags |= REG_NOTBOL;
-    if( noteol ) eflags |= REG_NOTEOL;
-#else
     GMatchInfo* pmatch{};
 
     int eflags = 0;
     if( notbol ) eflags |= G_REGEX_MATCH_NOTBOL;
     if( noteol ) eflags |= G_REGEX_MATCH_NOTEOL;
-#endif
 
-#ifdef POSIX_STYLE_REGEX_API
-    if( regexec( &creg.m_regex, asc_target, REGEX_MAX_NMATCH, pmatch, eflags ) != 0 ) {
-        return false;
-    }
-    constexpr int match_count = REGEX_MAX_NMATCH;
-#else
     if( ! g_regex_match( creg.m_regex, asc_target, GRegexMatchFlags( eflags ), &pmatch ) ) {
         g_match_info_free( pmatch );
         return false;
     }
     const int match_count = g_match_info_get_match_count( pmatch ) + 1;
-#endif
 
     for( int i = 0; i < match_count; ++i ){
 
-#ifdef POSIX_STYLE_REGEX_API
-        int so = pmatch[ i ].rm_so;
-        int eo = pmatch[ i ].rm_eo;
-#else
         int so;
         int eo;
         if( ! g_match_info_fetch_pos( pmatch, i, &so, &eo ) ) so = eo = -1;
-#endif
 
         if( so < 0 || eo < 0 ) {
             m_pos.push_back( so );
@@ -306,14 +255,26 @@ bool Regex::match( const RegexPattern& creg, const std::string& target,
         }
     }
 
-#ifndef POSIX_STYLE_REGEX_API
     g_match_info_free( pmatch );
-#endif
 
     return true;
 }
 
 
+bool Regex::match( const RegexPattern& creg, const std::string& target,
+                   const std::size_t offset, const bool notbol, const bool noteol,
+                   JDLIB::span<const std::string> named_captures )
+{
+    m_named_numbers.clear();
+    for( const std::string& name : named_captures ) {
+        const int num = g_regex_get_string_number( creg.m_regex, name.c_str() );
+        if( num != -1 ) m_named_numbers.emplace( name, num );
+    }
+
+    return match( creg, target, offset, notbol, noteol );
+}
+
+
 //
 // マッチした文字列と \0〜\9 を置換する
 //
@@ -365,3 +326,19 @@ std::string Regex::str( std::size_t num ) const
 
     return {};
 }
+
+
+/**
+ * @brief パターン中にグループ名が有れば名前付きキャプチャ、無ければグループ番号でマッチした部分を取得する。
+ *
+ * どちらにもマッチしなかったときは空文字列を返す
+ * @param[in] name グループ名
+ * @param[in] fallback_num パターン中にグループ名が無かったときに取得するグループ番号
+ */
+std::string Regex::named_or_num( const std::string& name, std::size_t fallback_num ) const
+{
+    const auto it = m_named_numbers.find( name );
+    if( it != m_named_numbers.end() ) return m_results[it->second];
+
+    return str( fallback_num );
+}
