@@ -1,7 +1,6 @@
 // ライセンス: GPL2
 
 //#define _DEBUG
-//#define _DEBUG_CHUNKED
 //#define _DEBUG_TIME
 #include "jddebug.h"
 
@@ -30,6 +29,7 @@
 #include <cstring>
 #include <mutex>
 #include <sstream>
+#include <system_error>
 
 #include <errno.h>
 #include <fcntl.h>
@@ -247,18 +247,241 @@ void JDLIB::check_loader_alive()
 using namespace JDLIB;
 
 
+/**
+ * @brief デコーダーの状態を初期化する
+ */
+void ChunkedDecoder::clear()
+{
+    m_state = State::parse_size;
+    m_lng_leftdata = 0;
+    m_buf_sizepart.clear();
+}
+
+
+/** @brief chunked なデータを切りつめる
+ *
+ * @param[in,out] buf 生データ -> 切りつめられたデータ (not null)
+ * @param[in,out] read_size 生データサイズ -> 出力データサイズ
+ * @return 生データが壊れていて処理できないときはfalse
+ */
+bool ChunkedDecoder::decode( char* buf, std::size_t& read_size )
+{
+    assert( buf );
+    std::size_t pos_chunk = 0;
+    std::size_t pos_body_start = 0; // データ部の先頭位置
+    std::size_t decoded_size = 0; // デコード済みのデータ長
+
+    while(1) {
+
+        // サイズ部
+        if( m_state == State::parse_size ) {
+
+            // サイズ部の途中でデータが途切れても再開できるように
+            // \r\nが来るまで m_buf_sizepart に文字をコピーしていく
+            for( ; pos_chunk < read_size; ++pos_chunk ) {
+
+                m_buf_sizepart.push_back( buf[pos_chunk] );
+
+                // \r\n が来たらデータ部のサイズを取得
+                if( const auto size = m_buf_sizepart.size();
+                        size >= 2 && m_buf_sizepart.compare( size - 2, 2, "\r\n" ) == 0 ) {
+
+                    char* end;
+                    m_lng_leftdata = std::strtoul( m_buf_sizepart.data(), &end, 16 );
+                    // 非数字で解析しなかったときもstrtoul()の結果が0になるためendをチェックする
+                    if( m_buf_sizepart.data() == end ) {
+                        MISC::ERRMSG( "broken chunked data that size part is not hexadecimal." );
+                        return false;
+                    }
+                    m_buf_sizepart.clear();
+
+                    // 最後のチャンク(長さ0)に達したら終了してトレーラー部は無視する
+                    if( m_lng_leftdata == 0 ) {
+                        read_size = decoded_size;
+                        buf[read_size] = '\0';
+                        m_state = State::completed;
+                        return true;
+                    }
+
+                    pos_chunk += 1; // \n をスキップする
+                    pos_body_start = pos_chunk;
+                    m_state = State::format_body;
+                    break;
+                }
+            }
+        }
+
+        // データ部
+        if( m_state == State::format_body ) {
+
+            // データを前に詰める
+            if( m_lng_leftdata ){
+                // 残りのチャンクデータと残りの入力バッファの少ないほう
+                const std::size_t cut_size = (std::min)( m_lng_leftdata, read_size - pos_chunk );
+                m_lng_leftdata -= cut_size;
+                pos_chunk += cut_size;
+
+                const std::size_t chunk_size = pos_chunk - pos_body_start;
+                if( decoded_size != pos_body_start && chunk_size ) {
+                    std::memmove( buf + decoded_size, buf + pos_body_start, chunk_size );
+                }
+                decoded_size += chunk_size;
+            }
+
+            // データを全部読み込んだらデータ部終わり
+            if( m_lng_leftdata == 0 ) m_state = State::check_body_cr;
+        }
+
+        // データ部→サイズ部切り替え中("\r"の前)
+        if( m_state == State::check_body_cr && pos_chunk != read_size ) {
+
+            if( buf[pos_chunk] != '\r' ) {
+                MISC::ERRMSG( "broken chunked data that is missing last CR." );
+                return false;
+            }
+            ++pos_chunk;
+            m_state = State::check_body_lf;
+        }
+
+        // データ部→サイズ部切り替え中("\n"の前: "\r" と "\n" の間でサーバからの入力が分かれる時がある)
+        if( m_state == State::check_body_lf && pos_chunk != read_size ) {
+
+            if( buf[pos_chunk] != '\n' ) {
+                MISC::ERRMSG( "broken chunked data that is missing last LF." );
+                return false;
+            }
+            ++pos_chunk;
+            m_state = State::parse_size;
+        }
+
+        // バッファ終わり
+        if( pos_chunk == read_size || m_state == State::completed ) {
+            read_size = decoded_size;
+            buf[read_size] = '\0';
+            // 処理の途中または完了したので m_state は変更しない
+            return true;
+        }
+    }
+    return true;
+}
+
+
+/**
+ * @brief デコーダーの状態を開放する
+ */
+void GzipDecoder::clear()
+{
+    m_buf_gzip_in.clear();
+    m_buf_gzip_out.clear();
+    m_lng_gzip_in = 0;
+    m_lng_gzip_out = 0;
+
+    if( m_use_gzip ) inflateEnd( &m_zstream );
+    m_use_gzip = false;
+
+    m_callback = nullptr;
+}
+
+
+/** @brief zlib 初期化
+ *
+ * @details `lng_buf` を基に入出力のバッファサイズを設定する
+ * @param[in] lng_buf   受信のバッファサイズ
+ * @param[in] callback  展開したデータを処理する関数ラッパー
+ * @return `true`なら初期化に成功した
+ */
+bool GzipDecoder::setup( std::size_t lng_buf, CallbackWrapper callback )
+{
+#ifdef _DEBUG
+    std::cout << "GzipDecoder::setup\n";
+#endif
+
+    m_use_gzip = true;
+    m_lng_gzip_in = lng_buf * 2;
+    m_lng_gzip_out = lng_buf * 10; // 小さいとパフォーマンスが落ちるので少し多めに10倍位
+    m_callback = std::move( callback );
+
+    // zlib 初期化
+    m_zstream.zalloc = Z_NULL;
+    m_zstream.zfree = Z_NULL;
+    m_zstream.opaque = Z_NULL;
+    m_zstream.next_in = Z_NULL;
+    m_zstream.avail_in = 0;
+
+    if( inflateInit2( &m_zstream, 15 + 32 ) != Z_OK ) // デフォルトの15に+32する( windowBits = 47 )と自動でヘッダ認識
+    {
+        MISC::ERRMSG( "GzipDecoder: inflateInit2 failed." );
+        return false;
+    }
+
+    // オーバーフロー対策としてマージンを追加してメモリを確保する
+    m_buf_gzip_in.resize( m_lng_gzip_in + kMargin );
+    m_buf_gzip_out.resize( m_lng_gzip_out + kMargin );
+
+    return true;
+}
+
+
+/** @brief gzip圧縮されたデータを展開してcallbackに渡す
+ *
+ * @param[in] gzip      gzip圧縮されたデータ
+ * @param[in] gzip_size 圧縮データのバイトサイズ
+ * @return 展開したデータのサイズ、または入力用バッファが不足したとき `std::nullopt` を返す
+ */
+std::optional<std::size_t> GzipDecoder::feed( const char* gzip, const std::size_t gzip_size )
+{
+    // オーバーフローのチェック
+    if( ( m_zstream.avail_in + gzip_size ) > m_lng_gzip_in ) {
+        MISC::ERRMSG( "GzipDecoder: Failed to decompress data due to short allocated buffer." );
+        return std::nullopt;
+    }
+    // zlibの入力バッファに値セット
+    std::memcpy( m_buf_gzip_in.data() + m_zstream.avail_in, gzip, gzip_size );
+    m_zstream.avail_in += gzip_size;
+    m_zstream.next_in = m_buf_gzip_in.data();
+
+    std::size_t total_out = 0;
+    std::size_t byte_out = 0;
+    do {
+        // 出力バッファセット
+        m_zstream.next_out = m_buf_gzip_out.data();
+        m_zstream.avail_out = m_lng_gzip_out;
+
+        // 展開
+        const int ret = inflate( &m_zstream, Z_NO_FLUSH );
+        if( ret == Z_OK || ret == Z_STREAM_END ) {
+
+            byte_out = m_lng_gzip_out - m_zstream.avail_out;
+            total_out += byte_out;
+
+#ifdef _DEBUG
+            std::cout << "inflate ok byte = " << byte_out << std::endl;
+#endif
+
+            // コールバック呼び出し
+            if( byte_out && m_callback ) {
+                m_callback( reinterpret_cast<char*>( m_buf_gzip_out.data() ), byte_out );
+            }
+        }
+        else return total_out;
+
+    } while ( byte_out );
+
+    // 入力バッファに使ってないデータが残っていたら前に移動
+    if( const auto avail_in = m_zstream.avail_in; avail_in ) {
+        std::memmove( m_buf_gzip_in.data(), m_buf_gzip_in.data() + ( gzip_size - avail_in ), avail_in );
+    }
+
+    return total_out;
+}
+
+
+
 //
 // low_priority = true の時はスレッド起動待ち状態になった時に、起動順のプライオリティを下げる
 //
 Loader::Loader( const bool low_priority )
-    : m_addrinfo( nullptr ),
-      m_stop( false ),
-      m_loading( false ),
-      m_low_priority( low_priority ),
-      m_buf( nullptr ),
-      m_buf_zlib_in ( nullptr ),
-      m_buf_zlib_out ( nullptr ),
-      m_use_zlib ( 0 )
+    : m_low_priority( low_priority )
 {
 #ifdef _DEBUG
     std::cout << "Loader::Loader : loader was created.\n";
@@ -274,6 +497,7 @@ Loader::~Loader()
     std::cout << "Loader::~Loader : url = " << m_data.url << std::endl;
 #endif
 
+    // m_thread.joinable() == true のときスレッドを破棄すると強制終了するため待機処理を入れる
     clear();
 
 //    assert( ! m_loading );
@@ -292,24 +516,17 @@ void Loader::clear()
     m_loadable = nullptr;
     
     m_use_chunk = false;
+    m_chunk_decoder.clear();
 
-    if( m_buf ) free( m_buf );
-    m_buf = nullptr;
+    m_buf.clear();
 
-    if( m_buf_zlib_in ) free( m_buf_zlib_in );
-    m_buf_zlib_in = nullptr;
-
-    if( m_buf_zlib_out ) free( m_buf_zlib_out );
-    m_buf_zlib_out = nullptr;
-    
-    if( m_use_zlib ) inflateEnd( &m_zstream );
-    m_use_zlib = false;
+    m_gzip_decoder.clear();
 }
 
 
 void Loader::wait()
 {
-    m_thread.join();
+    if( m_thread.joinable() ) m_thread.join();
 }
 
 
@@ -376,8 +593,6 @@ bool Loader::run( SKELETON::Loadable* cb, const LOADERDATA& data_in )
     // バッファサイズ設定
     m_data.size_buf = data_in.size_buf;
     m_lng_buf = MAX( LNG_BUF_MIN, m_data.size_buf * 1024 );
-    m_lng_buf_zlib_in = m_lng_buf * 2;
-    m_lng_buf_zlib_out = m_lng_buf * 10; // 小さいとパフォーマンスが落ちるので少し多めに10倍位
     
     // protocol と host と path 取得
     m_data.url = data_in.url;
@@ -522,29 +737,23 @@ void Loader::create_thread()
 #ifdef _DEBUG
     std::cout << "Loader::create_thread :  url = " << m_data.url << std::endl;
 #endif
+    if( m_thread.joinable() ) {
+        MISC::ERRMSG( "Loader::create_thread : thread is already running" );
+        return;
+    }
 
-    if( ! m_thread.create( ( STARTFUNC ) launcher, ( void * ) this, JDLIB::NODETACH ) ){
-
+    try {
+        m_thread = std::thread( &Loader::run_main, this );
+    }
+    catch( std::system_error& ) {
         m_data.code = HTTP_ERR;
         m_data.str_code = "Loader::run : could not start thread";
         MISC::ERRMSG( m_data.str_code );
         finish_loading();
-        return;
     }
 }
 
 
-//
-// スレッドのランチャ (static)
-//
-void* Loader::launcher( void* dat )
-{
-    Loader* tt = ( Loader * ) dat;
-    tt->run_main();
-    return nullptr;
-}
-
-
 bool Loader::send_connect( const int soc, std::string& errmsg )
 {
     std::string authority;
@@ -618,6 +827,7 @@ bool Loader::send_connect( const int soc, std::string& errmsg )
     return false;
 }
 
+
 //
 // 実際の処理部
 //
@@ -799,8 +1009,8 @@ void Loader::run_main()
     // 受信用バッファを作ってメッセージ受信
     size_t mrg;
     mrg = 64; // 一応オーバーフロー避けのおまじない
-    assert( m_buf == nullptr );
-    m_buf = ( char* )malloc( m_lng_buf + mrg );
+    assert( m_buf.empty() );
+    m_buf.resize( m_lng_buf + mrg );
 
     bool receiving_header;
 
@@ -834,7 +1044,7 @@ void Loader::run_main()
                     goto EXIT_LOADING;
                 }
 
-                tmpsize = recv( soc, m_buf + read_size, m_lng_buf - read_size - mrg, 0 );
+                tmpsize = recv( soc, m_buf.data() + read_size, m_lng_buf - read_size - mrg, 0 );
                 if( tmpsize < 0 && errno != EINTR ){
                     m_data.code = HTTP_ERR;         
                     errmsg = "recv() failed";
@@ -850,7 +1060,7 @@ void Loader::run_main()
             // SSL
             else{
 
-                tmpsize = ssl->read(  m_buf + read_size, m_lng_buf - read_size - mrg );
+                tmpsize = ssl->read( m_buf.data() + read_size, m_lng_buf - read_size - mrg );
                 if( tmpsize < 0 ){
                     m_data.code = HTTP_ERR;         
                     errmsg = ssl->get_errmsg() + " : " + m_data.url;
@@ -866,7 +1076,7 @@ void Loader::run_main()
                 // ヘッダ取得
                 if( receiving_header ){
 
-                    const int http_code = receive_header( m_buf, read_size );
+                    const int http_code = receive_header( m_buf.data(), read_size );
                     if( http_code == HTTP_ERR ){
 
                         m_data.code = HTTP_ERR;
@@ -911,35 +1121,41 @@ void Loader::run_main()
         
         //  chunkedな場合
         if( m_use_chunk ){
-            
-            if( !skip_chunk( m_buf, read_size ) ){
+
+            if( ! m_chunk_decoder.decode( m_buf.data(), read_size ) ) {
 
                 m_data.code = HTTP_ERR;
-                errmsg = "skip_chunk() failed : " + m_data.url;
+                errmsg = "ChunkedDecoder::decode() failed: " + m_data.url;
                 goto EXIT_LOADING;
             }
             if( ! read_size ) break;
         }
 
         // 圧縮されていない時はそのままコールバック呼び出し
-        if( !m_use_zlib ) {
+        if( ! m_gzip_decoder.is_decoding() ) {
 
             m_data.size_data += read_size;
 
             // コールバック呼び出し
-            if( m_loadable ) m_loadable->receive( m_buf, read_size );
+            if( m_loadable ) m_loadable->receive( m_buf.data(), read_size );
         }
-        
+
         // 圧縮されているときは unzip してからコールバック呼び出し
-        else if( !unzip( m_buf, read_size ) ){
-            
+        else if( auto expan_size = m_gzip_decoder.feed( m_buf.data(), read_size );
+                 expan_size.has_value() ) {
+
+            m_data.size_data += *expan_size;
+        }
+
+        else {
             m_data.code = HTTP_ERR;
             errmsg = "unzip() failed : " + m_data.url;
             goto EXIT_LOADING;
         }
 
         if( m_data.length && m_data.length <= m_data.length_current ) break;
-        
+        if( m_use_chunk && m_chunk_decoder.is_completed() ) break;
+
     } while( !m_stop );
 
 #ifdef _DEBUG_TIME
@@ -1232,15 +1448,18 @@ bool Loader::analyze_header()
     if( str_tmp.find( "chunked" ) != std::string::npos ){
         
         m_use_chunk = true;
-        m_status_chunk = 0;
-        m_pos_sizepart = m_str_sizepart;
+        m_chunk_decoder.clear();
     }
 
     // gzip か
-    m_use_zlib = false;
+    m_gzip_decoder.clear();
     str_tmp = analyze_header_option( "Content-Encoding: " );
     if( str_tmp.find( "gzip" ) != std::string::npos ){
-        if( !init_unzip() ) return false;
+        std::function callback = [p = m_loadable]( const char* buf, std::size_t size )
+        {
+            p->receive( buf, size );
+        };
+        if( ! m_gzip_decoder.setup( m_lng_buf, std::move( callback ) ) ) return false;
     }
 
 #ifdef _DEBUG
@@ -1254,7 +1473,7 @@ bool Loader::analyze_header()
     std::cout << "location = " << m_data.location << std::endl;
     std::cout << "contenttype = " << m_data.contenttype<< std::endl;            
     if( m_use_chunk ) std::cout << "m_use_chunk = true\n";
-    if( m_use_zlib )  std::cout << "m_use_zlib = true\n";
+    if( m_gzip_decoder.is_decoding() )  std::cout << "m_use_gzip = true\n";
 
     std::cout << "authenticate = " << analyze_header_option( "WWW-Authenticate: " ) << std::endl;
 
@@ -1268,7 +1487,7 @@ bool Loader::analyze_header()
 //
 // analyze_header() から呼ばれるオプションの値を取り出す関数
 //
-std::string Loader::analyze_header_option( const std::string& option ) const
+std::string Loader::analyze_header_option( std::string_view option ) const
 {
     const std::size_t i = MISC::ascii_ignore_case_find( m_data.str_header, option );
     if( i != std::string::npos ){
@@ -1286,7 +1505,7 @@ std::string Loader::analyze_header_option( const std::string& option ) const
 //
 // analyze_header() から呼ばれるオプションの値を取り出す関数(リスト版)
 //
-std::list< std::string > Loader::analyze_header_option_list( const std::string& option ) const
+std::list< std::string > Loader::analyze_header_option_list( std::string_view option ) const
 {
     std::list< std::string > str_list;
 
@@ -1310,207 +1529,6 @@ std::list< std::string > Loader::analyze_header_option_list( const std::string&
 
 
 
-
-//
-// chunked なデータを切りつめる関数
-//
-// 入力
-// buf : 生データ
-// readsize: 生データサイズ
-//
-// 出力
-// buf : 切りつめられたデータ
-// readsize: 出力データサイズ
-//
-bool Loader::skip_chunk( char* buf, size_t& read_size )
-{
-#ifdef _DEBUG_CHUNKED    
-    std::cout << "\n[[ skip_chunk : start read_size = " << read_size << " ]]\n";
-#endif    
-    
-    size_t pos_chunk = 0;
-    size_t pos_data_chunk_start = 0;
-    size_t buf_size = 0;
-    
-    for(;;){
-
-        // サイズ部
-        if( m_status_chunk == 0 ){  
-        
-            // \nが来るまで m_str_sizepart[] に文字をコピーしていく
-            for( ; pos_chunk < read_size; ++pos_chunk, ++m_pos_sizepart ){
-
-                // バッファオーバーフローのチェック
-                if( ( long )( m_pos_sizepart - m_str_sizepart ) >= 64 ){
-                    MISC::ERRMSG( "buffer over flow at skip_chunk" );
-                    return false;
-                }
-                
-                *( m_pos_sizepart ) =  buf[ pos_chunk ];
-
-                // \n が来たらデータ部のサイズを取得
-                if( buf[ pos_chunk ] == '\n' ){
-
-                    ++pos_chunk;
-                    
-                    *( m_pos_sizepart ) = '\0';
-                    if( *( m_pos_sizepart -1 ) == '\r' ) *( m_pos_sizepart -1 ) = '\0'; // "\r\n"の場合
-                    m_lng_leftdata = strtol( m_str_sizepart, nullptr, 16 );
-                    m_pos_sizepart = m_str_sizepart;
-                    
-#ifdef _DEBUG_CHUNKED
-                    std::cout << "[[ skip_chunk : size chunk finished : str = 0x" << m_str_sizepart << " ]]\n";                    
-                    std::cout << "[[ skip_chunk : enter the data chunk, data size = " << m_lng_leftdata << " ]]\n";
-#endif
-                    pos_data_chunk_start = pos_chunk;
-                    m_status_chunk = 1;
-                    
-                    break;
-                }
-            }
-        }
-
-        // データ部
-        if( m_status_chunk == 1 ){ 
-
-            // データを前に詰める
-            if( m_lng_leftdata ){
-                for( ; m_lng_leftdata > 0 && pos_chunk < read_size; --m_lng_leftdata, ++pos_chunk );
-                size_t buf_size_tmp = pos_chunk - pos_data_chunk_start;
-                if( buf_size != pos_data_chunk_start && buf_size_tmp ) memmove( buf + buf_size , buf + pos_data_chunk_start,  buf_size_tmp );
-                buf_size +=  buf_size_tmp;
-            }
-
-            // データを全部読み込んだらデータ部終わり
-            if( m_lng_leftdata == 0 ) m_status_chunk = 2;
-        }
-
-        // データ部→サイズ部切り替え中("\r"の前)
-        if( m_status_chunk == 2 && pos_chunk != read_size ){
-
-            if( buf[ pos_chunk++ ] != '\r' ){
-                MISC::ERRMSG( "broken chunked data." );
-                return false;
-            }
-
-            m_status_chunk = 3;
-        }
-
-        // データ部→サイズ部切り替え中("\n"の前: "\r" と "\n" の間でサーバからの入力が分かれる時がある)
-        if( m_status_chunk == 3 && pos_chunk != read_size ){
-
-            if( buf[ pos_chunk++ ] != '\n' ){
-                MISC::ERRMSG( "broken chunked data." );
-                return false;
-            }
-
-#ifdef _DEBUG_CHUNKED
-            std::cout << "[[ skip_chunk : data chunk finished. ]]\n";
-#endif
-            m_status_chunk = 0;
-        }
-
-        // バッファ終わり
-        if( pos_chunk == read_size ){
-            
-            read_size = buf_size;
-            buf[ read_size ] = '\0';
-            
-#ifdef _DEBUG_CHUNKED
-            std::cout << "[[ skip_chunk : output = " << read_size << " ]]\n\n";
-#endif
-            return true;
-        }
-    }
-
-    return true;
-}
-
-
-
-//
-// zlib 初期化
-//
-bool Loader::init_unzip()
-{
-#ifdef _DEBUG
-    std::cout << "Loader::init_unzip\n";
-#endif
-
-    m_use_zlib = true;
-        
-    // zlib 初期化
-    m_zstream.zalloc = Z_NULL;
-    m_zstream.zfree = Z_NULL;
-    m_zstream.opaque = Z_NULL;
-    m_zstream.next_in = Z_NULL;
-    m_zstream.avail_in = 0;
-
-    if ( inflateInit2( &m_zstream, 15 + 32 ) != Z_OK ) // デフォルトの15に+32する( windowBits = 47 )と自動でヘッダ認識
-    {
-        MISC::ERRMSG( "inflateInit2 failed." );
-        return false;
-    }
-
-    assert( m_buf_zlib_in == nullptr );
-    assert( m_buf_zlib_out == nullptr );
-    m_buf_zlib_in = ( Bytef* )malloc( sizeof( Bytef ) * m_lng_buf_zlib_in + 64 );
-    m_buf_zlib_out = ( Bytef* )malloc( sizeof( Bytef ) * m_lng_buf_zlib_out + 64 );
-
-    return true;
-}
-
-
-
-//
-// unzipしてコールバック呼び出し
-//
-bool Loader::unzip( char* buf, std::size_t read_size )
-{
-    // zlibの入力バッファに値セット
-    if( m_zstream.avail_in + read_size > m_lng_buf_zlib_in ){ // オーバーフローのチェック
-
-        MISC::ERRMSG( "buffer over flow at zstream_in : " + m_data.url );
-        return false;
-    }
-    memcpy( m_buf_zlib_in + m_zstream.avail_in , buf, read_size );
-    m_zstream.avail_in += read_size;
-    m_zstream.next_in = m_buf_zlib_in;
-            
-    size_t byte_out = 0;
-    do{
-
-        // 出力バッファセット
-        m_zstream.next_out = m_buf_zlib_out;
-        m_zstream.avail_out = m_lng_buf_zlib_out;
-
-        // 解凍
-        int ret = inflate( &m_zstream, Z_NO_FLUSH );
-        if( ret == Z_OK || ret == Z_STREAM_END ){
-            
-            byte_out = m_lng_buf_zlib_out - m_zstream.avail_out;
-            m_buf_zlib_out[ byte_out ] = '\0';
-            m_data.size_data += byte_out;
-            
-#ifdef _DEBUG
-            std::cout << "inflate ok byte = " << byte_out << std::endl;
-#endif
-            
-            // コールバック呼び出し
-            if( byte_out && m_loadable ) m_loadable->receive( ( char* )m_buf_zlib_out, byte_out );
-        }
-        else return true;
-                
-    } while ( byte_out );
-
-    // 入力バッファに使ってないデータが残っていたら前に移動
-    if( m_zstream.avail_in ) memmove( m_buf_zlib_in, m_buf_zlib_in + ( read_size - m_zstream.avail_in ),  m_zstream.avail_in );
-
-    return true;
-}
-
-
-
 //
 // sent, recv待ち
 //
