@@ -5,11 +5,14 @@
 #ifndef _MISCUTIL_H
 #define _MISCUTIL_H
 
-#include <string>
+
+#include <glibmm.h>
+
 #include <cstring>
 #include <list>
+#include <string>
+#include <string_view>
 #include <vector>
-#include <glibmm.h>
 
 namespace MISC
 {
@@ -25,24 +28,6 @@ namespace MISC
                 SCHEME_SSSP
 	};
 
-     // get_ucs2mode()の戻り値
-     enum
-     {
-         UCS2MODE_BASIC_LATIN = 0,
-         UCS2MODE_HIRA,
-         UCS2MODE_KATA,
-
-         UCS2MODE_OTHER
-     };
-
-
-     // utf8_fix_wavedash のモード
-     enum
-     {
-         UNIXtoWIN = 0,
-         WINtoUNIX
-     };
-
      // parse_html_form_data() の戻り値
      struct FormDatum
      {
@@ -88,33 +73,36 @@ namespace MISC
     // (例) {"aa", "", "bb", "cc"}, '!' -> "aa!bb!cc!"
     std::string concat_with_suffix( const std::list<std::string>& list_in, char suffix );
 
-    // strの前後の空白削除
-    std::string remove_space( const std::string& str );
+    /// str前後の半角スペース(U+0020)と全角スペース(U+3000)を削除
+    std::string utf8_trim( const std::string& str );
 
-    // str前後の改行、タブ、スペースを削除
-    std::string remove_spaces( const std::string& str );
+    /// str前後の改行(\r, \\n)、タブ(\t)、スペース(U+0020)を削除
+    std::string ascii_trim( const std::string& str );
 
-    // str1からstr2で示された文字列を除く
-    std::string remove_str( const std::string& str1, const std::string& str2 );
+    /// strからpatternで示された文字列を除く
+    std::string remove_str( std::string_view str, std::string_view pattern );
 
-    // start 〜 end の範囲をstrから取り除く ( /* コメント */ など )
-    std::string remove_str( const std::string& str, const std::string& start, const std::string& end );
+    /// start 〜 end の範囲をstrから取り除く ( /* コメント */ など )
+    std::string remove_str( std::string_view str, std::string_view start, std::string_view end );
 
     // 正規表現を使ってstr1からqueryで示された文字列を除く
     std::string remove_str_regex( const std::string& str1, const std::string& query );
 
-    // str1, str2 に囲まれた文字列を切り出す
-    std::string cut_str( const std::string& str, const std::string& str1, const std::string& str2 );
+    /// front_sep, back_sep に囲まれた文字列を切り出す
+    std::string cut_str( const std::string& str, std::string_view front_sep, std::string_view back_sep );
 
-    // str1 を str2 に置き換え
-    std::string replace_str( const std::string& str, const std::string& str1, const std::string& str2 );
+    /// pattern を replacement に置き換える
+    std::string replace_str( std::string_view str, std::string_view pattern, std::string_view replacement );
 
-    // list_inから str1 を str2 に置き換えてリストを返す
-    std::list< std::string > replace_str_list( const std::list< std::string >& list_in,
-                                               const std::string& str1, const std::string& str2 );
+    /// 文字列をコピーし部分文字列 old を new_ に置換して返す (ASCIIだけignore case)
+    std::string replace_casestr( const std::string& str, const std::string& old, const std::string& new_ );
 
-    // str_in に含まれる改行文字を replace に置き換え
-    std::string replace_newlines_to_str( const std::string& str_in, const std::string& replace );
+    /// list_inから pattern を replacement に置き換えてリストを返す
+    std::list<std::string> replace_str_list( const std::list<std::string>& list_in,
+                                             std::string_view pattern, std::string_view replacement );
+
+    /// str に含まれる改行文字(`\r\n`)を replace に置き換え
+    std::string replace_newlines_to_str( const std::string& str, std::string_view replace );
 
     // " を \" に置き換え
     std::string replace_quot( const std::string& str );
@@ -122,9 +110,6 @@ namespace MISC
     // \" を " に置き換え
     std::string recover_quot( const std::string& str );
 
-    // str 中に含まれている str2 の 数を返す
-    int count_str( const std::string& str, const std::string& str2 );
-
     // 文字列(utf-8も) -> 整数変換
     // (例) "12３" -> 123
     // 入力: str
@@ -140,7 +125,7 @@ namespace MISC
     // 16進数表記文字をバイナリに変換する( 例 "E38182" -> 0xE38182 )
     // 出力 : char_out 
     // 戻り値: 変換に成功した chr_in のバイト数
-    size_t chrtobin( const char* chr_in, char* chr_out );
+    std::size_t chrtobin( std::string_view chr_in, char* chr_out );
 
     // strが半角でmaxsize文字を超えたらカットして後ろに...を付ける
     std::string cut_str( const std::string& str, const unsigned int maxsize );
@@ -156,19 +141,21 @@ namespace MISC
     // 正規表現のメタ文字をアンエスケープ
     std::string regex_unescape( const std::string& str );
 
-    // HTMLエスケープ
-    // include_url : URL中でもエスケープする( デフォルト = true )
-    std::string html_escape( const std::string& str, const bool include_url = true );
+    // HTMLで特別な意味を持つ記号(& " < >)を文字実体参照へエスケープする
+    // completely : URL中でもエスケープする( デフォルト = true )
+    std::string html_escape( const std::string& str, const bool completely = true );
 
-    // HTMLアンエスケープ
+    // HTMLで特別な意味を持つ記号の文字実体参照(&quot; &amp; &lt; &gt;)をアンエスケープする
     std::string html_unescape( const std::string& str );
 
+    // HTMLをプレーンテキストに変換する
+    std::string to_plain( const std::string& html );
+
+    // HTMLをPango Markupテキストに変換する
+    std::string to_markup( const std::string& html );
+
     // HTML文字参照をデコード( completely=trueの場合は '&' '<' '>' '"' を含める )
-    std::string chref_decode( const char* str, const int lng, const bool completely = true );
-    inline std::string chref_decode( const std::string& str, const bool completely = true )
-    {
-        return MISC::chref_decode( str.c_str(), str.size(), completely );
-    }
+    std::string chref_decode( std::string_view str, const bool completely = true );
 
     // URL中のスキームを判別する
     // 戻り値 : スキームタイプ
@@ -184,8 +171,8 @@ namespace MISC
     // "RFC 2396" : http://www.ietf.org/rfc/rfc2396.txt
     bool is_url_char( const char* str_in, const bool loose_url );
 
-    // URLデコード
-    std::string url_decode( const std::string& url );
+    /// URLに含まれるパーセントエンコーディングをバイト列にデコードする
+    std::string url_decode( std::string_view url );
 
     // urlエンコード
     std::string url_encode( const char* str, const size_t n );
@@ -217,38 +204,26 @@ namespace MISC
     //
     int spchar_number_ln( const char* in_char, int& offset );
 
-    // 「&#数字;」形式の数字参照文字列を数字(int)に変換する
+    // 「&#数字;」形式の数値文字参照をコードポイント(char32_t)に変換する
+    char32_t decode_spchar_number_raw( const char* in_char, const int offset, const int lng );
+
+    // @brief 「&#数字;」形式の数値文字参照をコードポイント(char32_t)に変換する
     //
-    // 最初に MISC::spchar_number_ln() を呼び出して offset と lng を取得すること
+    // @details 数値文字参照の解析エラーとなる値は規定の値に変換して返す
+    // @param[in] in_char 入力文字列、 `in_char[0] == "&" && in_char[1] == "#"` であること (not null)
+    // @param[in] offset  spchar_number_ln() の戻り値
+    // @param[in] lng     spchar_number_ln() の戻り値
+    // @return 「&#数字;」の中の数字(char32_t型)
+    // @remarks 最初に MISC::spchar_number_ln() を呼び出して `offset` と `lng` を取得すること
     //
-    // in_char: 入力文字列、in_char[0] == "&" && in_char[1] == "#" であること
-    // offset : spchar_number_ln() の戻り値
-    // lng : spchar_number_ln() の戻り値
-    //
-    // 戻り値 : 「&#数字;」の中の数字(int型)
-    //
-    int decode_spchar_number( const char* in_char, const int offset, const int lng );
+    char32_t decode_spchar_number( const char* in_char, const int offset, const int lng );
+
+    // コードポイントが数値文字参照の無効・解析エラーなら規定の値へ変換する
+    char32_t sanitize_numeric_charref( const char32_t uch, char32_t* high_surrogate = nullptr );
 
     // str に含まれる「&#数字;」形式の数字参照文字列を全てユニーコード文字に変換する
     std::string decode_spchar_number( const std::string& str );
 
-    // utf-8 -> ucs2 変換
-    // 入力 : utfstr 入力文字 (UTF-8)
-    // 出力 :  byte  長さ(バイト) utfstr が ascii なら 1, UTF-8 なら 2 or 3 or 4 を入れて返す
-    // 戻り値 : ucs2
-    int utf8toucs2( const char* utfstr, int& byte );
-
-    // ucs2 の種類
-    int get_ucs2mode( const int ucs2 );
-
-    // ucs2 -> utf8 変換
-    // 出力 : utfstr 変換後の文字
-    // 戻り値 : バイト数
-    int ucs2toutf8( const int ucs2, char* utfstr );
-
-    // WAVEDASHなどのWindows系UTF-8文字をUnix系文字と相互変換
-    std::string utf8_fix_wavedash( const std::string& str, const int mode );
-
     // str を大文字化
     std::string toupper_str( const std::string& str );
 
@@ -282,6 +257,10 @@ namespace MISC
     // table_pos : 置き換えた文字列の位置
     void asc( const char* str1, std::string& str2, std::vector< int >& table_pos );
 
+    // UTF-8文字列(str1) -> 正規化文字列(str2)
+    // table_pos : 置き換えた文字列の位置
+    void norm( const char* str1, std::string& str2, std::vector<int>* table_pos = nullptr );
+
 
     // URL中のスキームを判別する
     inline int is_url_scheme( const char* str_in, int* length )
@@ -307,7 +286,7 @@ namespace MISC
 
     // haystack の pos 以降から最初に needle と一致する位置を返す (ASCIIだけignore case)
     // 見つからない場合は std::string::npos を返す、needle が空文字列なら pos を返す
-    std::size_t ascii_ignore_case_find( const std::string& haystack, const std::string& needle, std::size_t pos = 0 );
+    std::size_t ascii_ignore_case_find( const std::string& haystack, std::string_view needle, std::size_t pos = 0 );
 }
 
 
