@@ -78,9 +78,8 @@ PageNet::PageNet( Gtk::Window* parent )
 //
 void PageNet::slot_setup_proxy()
 {
-    SKELETON::PrefDiag* pref = CORE::PrefDiagFactory( m_parent, CORE::PREFDIAG_PROXY, "" );
+    auto pref = CORE::PrefDiagFactory( m_parent, CORE::PREFDIAG_PROXY, "" );
     pref->run();
-    delete pref;
 }
 
 
@@ -89,9 +88,8 @@ void PageNet::slot_setup_proxy()
 //
 void PageNet::slot_setup_browser()
 {
-    SKELETON::PrefDiag* pref = CORE::PrefDiagFactory( m_parent, CORE::PREFDIAG_BROWSER, "" );
+    auto pref = CORE::PrefDiagFactory( m_parent, CORE::PREFDIAG_BROWSER, "" );
     pref->run();
-    delete pref;
 
     m_label_browser.set_text( CONFIG::get_command_openurl() );
 }
@@ -280,13 +278,7 @@ SetupWizard::SetupWizard()
     set_title( "JDim セットアップウィザード" );
     set_keep_above( true );
     set_resizable( false );
-
-    const int width = 600;
-    const int height = 300;
-    const int sw = get_screen()->get_width();
-    const int sh = get_screen()->get_height();
-    resize( width, height );
-    if( sw > width && sh > height ) move( ( sw - width )/2, ( sh - height )/2 );
+    set_position( Gtk::WIN_POS_CENTER ); // 配置はデスクトップ環境次第
 
     // ボタン
     get_action_area()->set_spacing( SPACING_SIZE / 2 );
