@@ -28,10 +28,10 @@ namespace SKELETON
 
         JDEntry m_entry;
         bool m_enable_changed;
-        bool m_focused;
+        bool m_focused{};
 
         // ポップアップ
-        bool m_show_popup;
+        bool m_show_popup{};
         PopupWinBase m_popup_win;
         Gtk::ScrolledWindow m_scr_win;
         JDTreeViewBase m_treeview;
@@ -56,7 +56,7 @@ namespace SKELETON
         // 補完実行
         bool completion();
 
-        Glib::ustring get_text();
+        Glib::ustring get_text() const { return m_entry.get_text(); }
         void set_text( const Glib::ustring& text );
         void grab_focus();
 
