@@ -15,9 +15,8 @@ DetailDiag::DetailDiag( Gtk::Window* parent, const std::string& url,
                         const bool add_cancel,
                         const std::string& message, const std::string& tab_message,
                         const std::string& detail_html, const std::string& tab_detail )
-    : SKELETON::PrefDiag( parent, url, add_cancel ),
-      m_message( message ),
-      m_detail( nullptr )
+    : SKELETON::PrefDiag( parent, url, add_cancel )
+    , m_message( message )
 {
     m_message.set_width_chars( 60 );
     m_message.set_line_wrap( true );
@@ -25,7 +24,7 @@ DetailDiag::DetailDiag( Gtk::Window* parent, const std::string& url,
     m_message.set_selectable( true );
     m_message.property_can_focus() = false;
 
-    m_detail = CORE::ViewFactory( CORE::VIEW_ARTICLEINFO, get_url() );
+    m_detail.reset( CORE::ViewFactory( CORE::VIEW_ARTICLEINFO, get_url() ) );
     if( ! detail_html.empty() ) m_detail->set_command( "append_html", detail_html );
 
     m_notebook.append_page( m_message, tab_message );
@@ -39,10 +38,8 @@ DetailDiag::DetailDiag( Gtk::Window* parent, const std::string& url,
 }
 
 
-DetailDiag::~DetailDiag()
-{
-    if( m_detail ) delete m_detail;
-}
+// メンバーに不完全型のスマートポインターがあるためデストラクタはinlineにできない
+DetailDiag::~DetailDiag() noexcept = default;
 
 
 void DetailDiag::timeout()
@@ -53,6 +50,5 @@ void DetailDiag::timeout()
 
 void DetailDiag::slot_switch_page( Gtk::Widget*, guint page )
 {
-    if( get_notebook().get_nth_page( page ) == m_detail ) m_detail->redraw_view();
+    if( get_notebook().get_nth_page( page ) == m_detail.get() ) m_detail->redraw_view();
 }
-
