@@ -9,11 +9,11 @@ using namespace SKELETON;
 
 
 PopupWin::PopupWin( Gtk::Widget* parent, SKELETON::View* view, const int mrg_x, const int mrg_y )
-    : PopupWinBase( POPUPWIN_NOFRAME ),
-      m_parent( parent ),
-      m_view( view ),
-      m_mrg_x( mrg_x ),
-      m_mrg_y( mrg_y )
+    : PopupWinBase( POPUPWIN_NOFRAME )
+    , m_parent{ parent }
+    , m_view{ view }
+    , m_mrg_x{ mrg_x }
+    , m_mrg_y{ mrg_y }
 {
 #ifdef _DEBUG
     std::cout << "PopupWin::PopupWin\n";
@@ -32,23 +32,16 @@ PopupWin::PopupWin( Gtk::Widget* parent, SKELETON::View* view, const int mrg_x,
 }
 
 
-PopupWin::~PopupWin()
-{
-    if( m_view ) delete m_view;
-}
-
-
 //
 // ポップアップウィンドウの座標と幅と高さを計算して移動とリサイズ
 //
 void PopupWin::slot_resize_popup()
 {
     if( ! m_view ) return;
-    
+
     // マウス座標
     int x_mouse, y_mouse;
-    // TODO: Use Gdk::Display::get_default_seat() instead of get_device_manager() (since 3.20)
-    Gdk::Display::get_default()->get_device_manager()->get_client_pointer()->get_position( x_mouse, y_mouse );
+    Gdk::Display::get_default()->get_default_seat()->get_pointer()->get_position( x_mouse, y_mouse );
 
     // クライアントのサイズを取得
     const int width_client = m_view->width_client();
