@@ -112,7 +112,7 @@ void Usrcmd_Manager::analyze_xml()
 
 void Usrcmd_Manager::set_cmd( const std::string& cmd )
 {
-    std::string cmd2 = MISC::remove_space( cmd );
+    std::string cmd2 = MISC::utf8_trim( cmd );
     m_list_cmd.push_back( cmd2 );
 
 #ifdef _DEBUG
@@ -192,14 +192,14 @@ void Usrcmd_Manager::exec( const std::string& command, // コマンド
     if( cmd.rfind( "$VIEW", 0 ) == 0 ){
         use_browser = true;
         cmd = cmd.substr( 5 );
-        cmd = MISC::remove_space( cmd );
+        cmd = MISC::utf8_trim( cmd );
     }
 
     bool show_dialog = false;
     if( cmd.rfind( "$DIALOG", 0 ) == 0 ){
         show_dialog = true;
         cmd = cmd.substr( 7 );
-        cmd = MISC::remove_space( cmd );
+        cmd = MISC::utf8_trim( cmd );
     }
 
     cmd = replace_cmd( cmd, url, link, selection, number );
@@ -280,7 +280,7 @@ std::string Usrcmd_Manager::replace_cmd( const std::string& cmd,
     cmd_out = MISC::replace_str( cmd_out, "$DATNAMEL", DBTREE::article_key( link ) );
     cmd_out = MISC::replace_str( cmd_out, "$DATNAME", DBTREE::article_key( url ) );
 
-    cmd_out = MISC::replace_str( cmd_out, "$TITLE", DBTREE::article_subject( url ) );
+    cmd_out = MISC::replace_str( cmd_out, "$TITLE", MISC::to_plain( DBTREE::article_subject( url ) ) );
     cmd_out = MISC::replace_str( cmd_out, "$BOARDNAME", DBTREE::board_name( url ) );
 
     // 範囲選択した文字列
