@@ -88,6 +88,9 @@ SKELETON::View* CORE::ViewFactory( int type, const std::string& url, VIEWFACTORY
         case VIEW_ARTICLEPOST:
             return new ARTICLE::ArticleViewPost( url );
 
+        case VIEW_ARTICLEHIGHREFRES:
+            return new ARTICLE::ArticleViewHighRefRes( url );
+
         case VIEW_ARTICLEURL:
             return new ARTICLE::ArticleViewURL( url );
 
